@@ -3,6 +3,7 @@
 import flask
 from flask import current_app
 import json
+from rfhub.version import __version__
 
 blueprint = flask.Blueprint('doc', __name__,
                             template_folder="templates",
@@ -20,6 +21,7 @@ def doc():
 
     return flask.render_template("home.html",
                                  data={"libraries": libraries,
+                                       "version": __version__,
                                        "libdoc": None,
                                        "hierarchy": hierarchy,
                                        "resource_files": resource_files
@@ -36,6 +38,7 @@ def index():
 
     return flask.render_template("libraryNames.html",
                                  data={"libraries": libraries,
+                                       "version": __version__,
                                        "resource_files": resource_files
                                    })
 
@@ -45,22 +48,38 @@ def search():
     """Show all keywords that match a pattern"""
     pattern = flask.request.args.get('pattern', "*").strip().lower()
 
-    keywords = []
+    # if the pattern contains "in:<collection>" (eg: in:builtin),
+    # filter results to only that (or those) collections
+    # This was kind-of hacked together, but seems to work well enough
+    collections = [c["name"].lower() for c in current_app.kwdb.get_collections()]
+    words = []
+    filters = []
+    for word in pattern.split(" "):
+        if word.lower().startswith("in:"):
+            filters.extend([name for name in collections if name.startswith(word[3:])])
+        else:
+            words.append(word)
+    pattern = " ".join(words)
 
+    keywords = []
     for keyword in current_app.kwdb.search(pattern):
         kw = list(keyword)
-        url = flask.url_for(".doc_for_library", library=kw[0], keyword=kw[1])
-        row_id = "row-%s.%s" % (keyword[0].lower(), keyword[1].lower().replace(" ","-"))
-        keywords.append({"collection": keyword[0],
-                         "name": keyword[1],
-                         "synopsis": keyword[2],
-                         "url": url,
-                         "row_id": row_id
-                     })
+        collection = kw[0].lower()
+        if len(filters) == 0 or collection in filters:
+            url = flask.url_for(".doc_for_library", library=kw[0], keyword=kw[1])
+            row_id = "row-%s.%s" % (keyword[0].lower(), keyword[1].lower().replace(" ","-"))
+            keywords.append({"collection": keyword[0],
+                             "name": keyword[1],
+                             "synopsis": keyword[2],
+                             "version": __version__,
+                             "url": url,
+                             "row_id": row_id
+                         })
 
     keywords.sort(key=lambda kw: kw["name"])
     return flask.render_template("search.html",
                                  data={"keywords": keywords,
+                                       "version": __version__,
                                        "pattern": pattern
                                    })
 
@@ -93,6 +112,7 @@ def doc_for_library(library, keyword=""):
 
     return flask.render_template("library.html",
                                  data={"keywords": keywords,
+                                       "version": __version__,
                                        "libdoc": libdoc,
                                        "hierarchy": hierarchy})
 
