@@ -32,7 +32,7 @@ I haven't done extensive testing.
 """
 
 class WatchdogHandler(PatternMatchingEventHandler):
-    patterns = ["*.robot", "*.txt", "*.py"]
+    patterns = ["*.robot", "*.txt", "*.py", "*.tsv"]
     def __init__(self, kwdb, path):
         PatternMatchingEventHandler.__init__(self)
         self.kwdb = kwdb
@@ -66,7 +66,7 @@ class KeywordTable(object):
         self.observer.start()
 
     def add(self, name, monitor=True):
-        """Add a folder, library (.py) or resource file (.robot, .txt) to the database
+        """Add a folder, library (.py) or resource file (.robot, .tsv, .txt) to the database
         """
 
         if os.path.isdir(name):
@@ -171,8 +171,8 @@ class KeywordTable(object):
                     if len(line.strip()) > 0:
                         exclude_patterns.append(line)
         except:
+            # should probably warn the user?
             pass
-        print dirname, "exclude_patterns:", exclude_patterns
 
         for filename in os.listdir(dirname):
             path = os.path.join(dirname, filename)
@@ -184,7 +184,7 @@ class KeywordTable(object):
                         if os.access(path, os.R_OK):
                             self.add_folder(path, watch=False)
                 else:
-                    if (ext in (".xml", ".robot", ".txt", ".py")):
+                    if (ext in (".xml", ".robot", ".txt", ".py", ".tsv")):
                         if os.access(path, os.R_OK):
                             self.add(path)
             except Exception, e:
@@ -445,7 +445,8 @@ class KeywordTable(object):
 
         found_keyword_table = False
         if (name.lower().endswith(".robot") or
-            name.lower().endswith(".txt")) :
+            name.lower().endswith(".txt") or
+            name.lower().endswith(".tsv")):
 
             with open(name, "r") as f:
                 data = f.read()
